@@ -16,13 +16,11 @@
 #' @param ylab Label for `y` axis variable (Default: `"term"`).
 #' @param title The text for the plot title.
 #' @param subtitle The text for the plot subtitle.
-#' @param effects In case the object is of class `merMod`
-#'   (`lmerMod`, `glmerMod`, `nlmerMod`), these arguments determine which
-#'   effects are to be displayed. By default, only the `"fixed"` effects will be
-#'   shown. Other option is `"ran_pars"`.
-#' @param ran.prefix A length-2 character vector specifying the strings to use
-#'   as prefixes for self- (variance/standard deviation) and cross- (covariance
-#'   /correlation) random effects terms.
+#' @param conf.method Character describing method for computing confidence
+#'   intervals (for more, see `lme4::confint.merMod`).
+#' @param p.kr Logical, if `TRUE`, the computation of p-values for `lmer` is
+#'   based on conditional F-tests with Kenward-Roger approximation for the df.
+#'   For details, see `?sjstats::p_value`.
 #' @param point.color Character describing color for the point (Default:
 #'   `"blue"`).
 #' @param point.size Numeric specifying size for the point (Default: `3`).
@@ -57,7 +55,7 @@
 #'   (Default: `"dashed"`).
 #' @param vline.size Numeric specifying the size of the vertical line (Default:
 #'   `1`).
-#' @param sort `"none"` (default) do not sort, `"ascending"` sort by increasing
+#' @param sort If `"none"` (default) do not sort, `"ascending"` sort by increasing
 #'   coefficient value, or `"descending"` sort by decreasing coefficient value.
 #' @param stats.labels Logical. Decides whether the statistic and p-values for
 #'   each coefficient are to be attached to each dot as a text label using
@@ -123,25 +121,26 @@
 #' @importFrom grid unit
 #' @importFrom magrittr "%>%"
 #' @importFrom magrittr "%<>%"
-#' @importFrom lmerTest as_lmerModLmerTest
+#' @importFrom sjstats p_value
 #' @importFrom tibble rownames_to_column
 #' @importFrom tibble as_data_frame
 #'
-#' @examples
+#' @references
+#' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/ggcoefstats.html}
 #'
+#' @examples
+#' 
 #' set.seed(123)
 #' ggcoefstats(x = lm(formula = mpg ~ cyl * am, data = mtcars))
-#'
 #' @export
 #'
 
 # function body
 ggcoefstats <- function(x,
                         output = "plot",
-                        effects = "fixed",
                         scales = NULL,
-                        ran.prefix = NULL,
                         conf.method = "Wald",
+                        p.kr = TRUE,
                         coefficient.type = "beta",
                         effsize = "eta",
                         nboot = 1000,
@@ -190,27 +189,37 @@ ggcoefstats <- function(x,
                         label.direction = "y",
                         ggtheme = ggplot2::theme_bw(),
                         ...) {
-  #====================================== creating a list of objects ==================================================================
+  # ================================== list of objects (for tidy and glance) ==========================================================
 
-  # models for which statistic is t-value
-  t.mods <- c("lmerMod", "lm", "nls", "lmRob", "rq")
-
-  # models for which statistic is z-value
-  z.mods <- c("glm", "glmerMod", "glmRob", "clm", "clmm")
-
-  # creating a list of objects which will have "effects" or "groups" in their summary outputs
+  # creating a list of objects which will have fixed and random "effects"
+  # only fixed effects will be selected
   lmm.mods <- c("lmerMod", "glmerMod", "nlmerMod")
 
-  # models for which statistic is t-value
-  f.mods <- c("aov", "aovlist")
-
   # models which are currently not supported
-  unsupported.mods <- c("glht", "rlm", "kmeans", "rq")
+  unsupported.mods <- c("glht", "kmeans", "rq")
 
   # models for which glance is not supported
   noglance.mods <- c("aovlist")
 
-  #====================================== checking if object is supported =============================================================
+  # models for which the diagnostics is not available (AIC, BIC, loglik)
+  nodiagnostics.mods <- c("lmRob", "glmRob")
+
+  # ================================== list of objects (for statistic) ================================================================
+
+  # models for which statistic is t-value
+  t.mods <- c("lmerMod", "lm", "nls", "lmRob", "rq", "rlm")
+
+  # models for which statistic is z-value
+  z.mods <- c("clm", "clmm")
+
+  # models for which statistic is F-value
+  f.mods <- c("aov", "aovlist")
+
+  # models for which there is no clear t-or z-statistic
+  # which statistic to use will be decided based on the family used
+  g.mods <- c("glm", "glmerMod", "glmRob")
+
+  # ====================================== checking if object is supported =============================================================
   # glace is not supported for all models
   if (class(x)[[1]] %in% unsupported.mods) {
     base::stop(base::message(cat(
@@ -222,12 +231,12 @@ ggcoefstats <- function(x,
       )
     )))
   }
-  #================================================== model and its summary ===========================================================
+  # ================================================== model and its summary ===========================================================
 
   # glance object from broom
   if (!(class(x)[[1]] %in% noglance.mods)) {
-      glance_df <- broom::glance(x = x) %>%
-        tibble::as_data_frame(x = .)
+    glance_df <- broom::glance(x = x) %>%
+      tibble::as_data_frame(x = .)
   } else {
     base::message(cat(
       crayon::green("Note:"),
@@ -240,20 +249,22 @@ ggcoefstats <- function(x,
   }
 
   # tidy dataframe of results from the model
-  # if these are merMod objects, choose whether the random effects are to be displayed
+  # ===================================== lmm tidying =======================================================================
   if (class(x)[[1]] %in% lmm.mods) {
-      tidy_df <-
-        broom::tidy(
-          x = x,
-          conf.int = TRUE,
-          conf.level = conf.level,
-          effects = effects,
-          scales = scales,
-          ran_prefix = ran.prefix,
-          conf.method = conf.method,
-          ...
-        )
+    tidy_df <-
+      broom::tidy(
+        x = x,
+        conf.int = TRUE,
+        conf.level = conf.level,
+        effects = "fixed",
+        scales = scales,
+        conf.method = conf.method,
+        ...
+      )
   } else if (class(x)[[1]] %in% f.mods) {
+
+    # ===================================== aov tidying =======================================================================
+    #
     tidy_df <- lm_effsize_ci(
       object = x,
       effsize = effsize,
@@ -273,13 +284,16 @@ ggcoefstats <- function(x,
         dplyr::rename(.data = ., estimate = partial.omegasq)
       xlab <- "partial omega-squared"
     }
-  } else if (class(x)[[1]] == "clm" || class(x)[[1]] == "clmm" ) {
+    # ===================================== clm and clmm tidying =======================================================================
+  } else if (class(x)[[1]] == "clm" || class(x)[[1]] == "clmm") {
     tidy_df <-
-      broom::tidy(x = x,
-                  conf.int = TRUE,
-                  conf.level = conf.level,
-                  quick = FALSE,
-                  conf.type = "Wald")
+      broom::tidy(
+        x = x,
+        conf.int = TRUE,
+        conf.level = conf.level,
+        quick = FALSE,
+        conf.type = "Wald"
+      )
 
     # selecting which coeffiecients to display
     if (coefficient.type == "alpha") {
@@ -290,28 +304,48 @@ ggcoefstats <- function(x,
         dplyr::filter(.data = ., coefficient_type == "beta")
     }
 
+    # ===================================== tidying robust models =======================================================================
+  } else if (class(x)[[1]] == "lmRob" || class(x)[[1]] == "glmRob") {
+    tidy_df <-
+      broom::tidy(x = x)
+    # ===================================== tidying everything else =======================================================================
   } else {
     tidy_df <-
-      broom::tidy(x = x,
-                  conf.int = TRUE,
-                  conf.level = conf.level)
+      broom::tidy(
+        x = x,
+        conf.int = TRUE,
+        conf.level = conf.level
+      )
   }
 
+  # ===================================== p-value computation =======================================================================
+  #
   # p-values won't be computed by default for the lmer models
-  if (class(x)[[1]] == "lmerMod") {
+  if (class(x)[[1]] == "lmerMod" || class(x)[[1]] == "rlm") {
     # computing p-values
-    lmer_p <-
-      coef(summary(lmerTest::as_lmerModLmerTest(model = x, tol = 1e-08))) %>%
-      base::as.data.frame(.) %>%
-      tibble::rownames_to_column(df = ., var = "term") %>%
-      dplyr::select(.data = ., term, p.value = `Pr(>|t|)`) %>%
-      tibble::as_data_frame(x = .)
-
-    # merging the two dataframes
-    tidy_df <-
-      dplyr::full_join(x = tidy_df, y = lmer_p, by = "term")
+    tidy_df %<>%
+      tibble::as_data_frame(x = .) %>%
+      dplyr::mutate_at(
+        .tbl = .,
+        .vars = "term",
+        .funs = ~as.character(x = .)
+      ) %>%
+      dplyr::full_join(
+        x = .,
+        y = sjstats::p_value(fit = x, p.kr = p.kr) %>%
+          tibble::as_data_frame(x = .) %>%
+          dplyr::select(.data = ., -std.error) %>%
+          dplyr::mutate_at(
+            .tbl = .,
+            .vars = "term",
+            .funs = ~as.character(x = .)
+          ),
+        by = "term"
+      )
   }
 
+  # ===================================== p-value and CI check =======================================================================
+  #
   # if broom output doesn't contain p-value
   if (!"p.value" %in% names(tidy_df)) {
     # skip the labels
@@ -328,42 +362,70 @@ ggcoefstats <- function(x,
     ))
   }
 
-  #=============================  intercept, exponentiation, and final tidy dataframe ================================================
+  # if broom output doesn't contain CI
+  if (!"conf.low" %in% names(tidy_df)) {
+    # add NAs so that only dots will be shown
+    tidy_df %<>%
+      dplyr::mutate(
+        .data = .,
+        conf.low = NA_character_,
+        conf.high = NA_character_
+      )
+
+    # stop displaying whiskers
+    conf.int <- FALSE
+
+    # inform the user that skipping labels for the same reason
+    base::message(cat(
+      crayon::green("Note:"),
+      crayon::blue(
+        "No 95% confidence intervals available for regression coefficients from",
+        crayon::yellow(class(x)[[1]]),
+        "object, so skipping whiskers in the plot."
+      )
+    ))
+  }
+
+  # =============================  intercept, exponentiation, and final tidy dataframe ================================================
 
   # ordering the dataframe
   tidy_df %<>%
-    dplyr::select(.data = .,
-                  term,
-                  estimate,
-                  conf.low,
-                  conf.high,
-                  dplyr::everything())
+    dplyr::select(
+      .data = .,
+      term,
+      estimate,
+      conf.low,
+      conf.high,
+      dplyr::everything()
+    )
 
   # whether to show model intercept; if not, remove the corresponding terms from the dataframe
   if (isTRUE(exclude.intercept)) {
     tidy_df %<>%
-      dplyr::filter(.data = .,
-                    !base::grepl(
-                      pattern = "(Intercept)",
-                      x = term,
-                      ignore.case = TRUE
-                    ))
+      dplyr::filter(
+        .data = .,
+        !base::grepl(
+          pattern = "(Intercept)",
+          x = term,
+          ignore.case = TRUE
+        )
+      )
   }
 
   # if the coefficients are to be exponentiated, the label positions will also have to be adjusted
   if (isTRUE(exponentiate)) {
-    #tidy_df$estimate <- base::exp(tidy_df$estimate)
+    # tidy_df$estimate <- base::exp(tidy_df$estimate)
     tidy_df %<>%
       dplyr::mutate_at(
         .tbl = .,
         .vars = dplyr::vars(dplyr::matches(
           match = "estimate|conf", ignore.case = TRUE
         )),
-        .funs = ~ base::exp(x = .)
+        .funs = ~base::exp(x = .)
       )
   }
 
-  #========================================================= stats labels =========================================================
+  # ========================================================= p-value formatting =========================================================
   #
   # formatting the numbers for display and preparing labels
   if (isTRUE(stats.labels)) {
@@ -371,12 +433,12 @@ ggcoefstats <- function(x,
       dplyr::mutate_at(
         .tbl = .,
         .vars = "statistic",
-        .funs = ~ ggstatsplot::specify_decimal_p(x = ., k = k)
+        .funs = ~ggstatsplot::specify_decimal_p(x = ., k = k)
       ) %>%
       signif_column(data = ., p = p.value) %>%
       purrrlyr::by_row(
         .d = .,
-        ..f = ~ ggstatsplot::specify_decimal_p(
+        ..f = ~ggstatsplot::specify_decimal_p(
           x = .$p.value,
           k = k,
           p.value = TRUE
@@ -393,64 +455,111 @@ ggcoefstats <- function(x,
         )
       )
 
-    #========================================================= t-statistic =========================================================
+    # ========================================================= t-statistic labels =========================================================
     if (class(x)[[1]] %in% t.mods) {
       tidy_df %<>%
-        purrrlyr::by_row(
-          .d = .,
-          ..f = ~ paste(
-            "list(~italic(beta)==",
-            ggstatsplot::specify_decimal_p(x = .$estimate, k = k),
-            ", ~italic(t)",
-            "(",
-            glance_df$df.residual,
-            ")==",
-            .$statistic,
-            ", ~italic(p)",
-            .$p.value.formatted2,
-            ")",
-            sep = ""
-          ),
-          .collate = "rows",
-          .to = "label",
-          .labels = TRUE
+        tz_labeller(
+          tidy_df = .,
+          glance_df = glance_df,
+          statistic = "t",
+          k = k
         )
-      # if random effects are displayed, then remove labels since no p-values are available
-      if (effects != "fixed") {
-        tidy_df %<>%
-          dplyr::mutate(
-            .data = .,
-            label = dplyr::case_when(is.na(p.value) ~ NA_character_,
-                                     TRUE ~ label)
-          )
-      }
-
-      #========================================================= z-statistic =========================================================
+      # ========================================================= z-statistic labels =========================================================
     } else if (class(x)[[1]] %in% z.mods) {
       tidy_df %<>%
-        purrrlyr::by_row(
-          .d = .,
-          ..f = ~ paste(
-            "list(~italic(beta)==",
-            ggstatsplot::specify_decimal_p(x = .$estimate, k = k),
-            ", ~italic(z)==",
-            .$statistic,
-            ", ~italic(p)",
-            .$p.value.formatted2,
-            ")",
-            sep = ""
-          ),
-          .collate = "rows",
-          .to = "label",
-          .labels = TRUE
+        tz_labeller(
+          tidy_df = .,
+          glance_df = glance_df,
+          statistic = "z",
+          k = k
         )
-      #========================================================= F-statistic =========================================================
+
+      # ========================================================= t/z-statistic labels =========================================================
+    } else if (class(x)[[1]] %in% g.mods) {
+      if (class(x)[[1]] == "glm") {
+        if (summary(x)$family$family[[1]] %in% c(
+          "quasi",
+          "gaussian",
+          "quasibinomial",
+          "quasipoisson",
+          "Gamma",
+          "inverse.gaussian"
+        )) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "t",
+              k = k
+            )
+        } else if (summary(x)$family$family[[1]] %in% c("binomial", "poisson")) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "z",
+              k = k
+            )
+        }
+      } else if (class(x)[[1]] == "glmerMod") {
+        if (summary(x)$family[[1]] %in% c(
+          "quasi",
+          "gaussian",
+          "quasibinomial",
+          "quasipoisson",
+          "Gamma",
+          "inverse.gaussian"
+        )) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "t",
+              k = k
+            )
+        } else if (summary(x)$family[[1]] %in% c("binomial", "poisson")) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "z",
+              k = k
+            )
+        }
+      } else if (class(x)[[1]] == "glmRob") {
+        if (x$family[[1]] %in% c(
+          "quasi",
+          "gaussian",
+          "quasibinomial",
+          "quasipoisson",
+          "Gamma",
+          "inverse.gaussian"
+        )) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "t",
+              k = k
+            )
+        } else if (x$family[[1]] %in% c("binomial", "poisson")) {
+          tidy_df %<>%
+            tz_labeller(
+              tidy_df = .,
+              glance_df = glance_df,
+              statistic = "z",
+              k = k
+            )
+        }
+      }
+      # ========================================================= F-statistic =========================================================
     } else if (class(x)[[1]] %in% f.mods) {
+      # which effect size is needed?
       if (effsize == "eta") {
         tidy_df %<>%
           purrrlyr::by_row(
             .d = .,
-            ..f = ~ paste(
+            ..f = ~paste(
               "list(~italic(F)",
               "(",
               .$df1,
@@ -473,7 +582,7 @@ ggcoefstats <- function(x,
         tidy_df %<>%
           purrrlyr::by_row(
             .d = .,
-            ..f = ~ paste(
+            ..f = ~paste(
               "list(~italic(F)",
               "(",
               .$df1,
@@ -496,33 +605,40 @@ ggcoefstats <- function(x,
     }
   }
 
-  #================================================== summary caption ===========================================================
+  # ================================================== summary caption ===========================================================
 
   # caption containing model diagnostics
   if (isTRUE(caption.summary)) {
-    if (!(class(x)[[1]] %in% noglance.mods)) {
-      caption.text <-
-        base::substitute(
-          expr =
-            paste("AIC = ",
-                  AIC,
-                  ", BIC = ",
-                  BIC,
-                  ", log-likelihood = ",
-                  loglik),
-          env = base::list(
-            AIC = ggstatsplot::specify_decimal_p(x = glance_df$AIC[[1]], k = k.caption.summary),
-            BIC = ggstatsplot::specify_decimal_p(x = glance_df$BIC[[1]], k = k.caption.summary),
-            loglik = ggstatsplot::specify_decimal_p(x = glance_df$logLik[[1]], k = k.caption.summary)
+    if (!(class(x)[[1]] %in% noglance.mods) && !(class(x)[[1]] %in% nodiagnostics.mods)) {
+      if (!is.na(glance_df$AIC[[1]])) {
+        # preparing caption with model diagnostics
+        caption.text <-
+          base::substitute(
+            expr =
+              paste(
+                "AIC = ",
+                AIC,
+                ", BIC = ",
+                BIC,
+                ", log-likelihood = ",
+                loglik
+              ),
+            env = base::list(
+              AIC = ggstatsplot::specify_decimal_p(x = glance_df$AIC[[1]], k = k.caption.summary),
+              BIC = ggstatsplot::specify_decimal_p(x = glance_df$BIC[[1]], k = k.caption.summary),
+              loglik = ggstatsplot::specify_decimal_p(x = glance_df$logLik[[1]], k = k.caption.summary)
+            )
           )
-        )
+      } else {
+        caption.text <- NULL
+      }
     } else {
       caption.text <- NULL
     }
   } else {
     caption.text <- NULL
   }
-  #================================================== basic plot ===========================================================
+  # ================================================== basic plot ===========================================================
 
   # whether the term need to be arranged in any specified order
   if (sort != "none") {
@@ -537,7 +653,8 @@ ggcoefstats <- function(x,
       base::factor(x = tidy_df$term, levels = tidy_df$term[new_order])
   } else {
     tidy_df$term <- base::as.factor(tidy_df$term)
-    tidy_df %<>% tibble::rownames_to_column(df = ., var = "rowid")
+    tidy_df %<>%
+      tibble::rownames_to_column(., var = "rowid")
     new_order <- base::order(tidy_df$rowid, decreasing = FALSE)
     tidy_df$term <- as.character(tidy_df$term)
     tidy_df$term <-
@@ -547,8 +664,10 @@ ggcoefstats <- function(x,
 
   # setting up the basic architecture
   plot <-
-    ggplot2::ggplot(data = tidy_df,
-                    mapping = ggplot2::aes(x = estimate, y = factor(term)))
+    ggplot2::ggplot(
+      data = tidy_df,
+      mapping = ggplot2::aes(x = estimate, y = factor(term))
+    )
 
   # adding the vertical line, either at 1 if coefficients are exponentiated or to 0 if not
   if (isTRUE(vline)) {
@@ -575,16 +694,17 @@ ggcoefstats <- function(x,
   }
 
   # if the confidence intervals are to be displayed on the plot
-  if (isTRUE(conf.int))
+  if (isTRUE(conf.int)) {
     plot <- plot +
-    ggplot2::geom_errorbarh(
-      ggplot2::aes_string(xmin = "conf.low", xmax = "conf.high"),
-      color = errorbar.color,
-      height = errorbar.height,
-      linetype = errorbar.linetype,
-      size = errorbar.size,
-      na.rm = TRUE
-    )
+      ggplot2::geom_errorbarh(
+        ggplot2::aes_string(xmin = "conf.low", xmax = "conf.high"),
+        color = errorbar.color,
+        height = errorbar.height,
+        linetype = errorbar.linetype,
+        size = errorbar.size,
+        na.rm = TRUE
+      )
+  }
 
   # changing the point aesthetics
   plot <- plot +
@@ -595,7 +715,7 @@ ggcoefstats <- function(x,
       na.rm = TRUE
     )
 
-  #================================================== ggrepel labels ===========================================================
+  # ================================================== ggrepel labels ===========================================================
 
   if (isTRUE(stats.labels)) {
     # adding the labels
@@ -629,7 +749,7 @@ ggcoefstats <- function(x,
       )
   }
 
-  #================================================== other plot labels ===========================================================
+  # ================================================== other plot labels ===========================================================
   #
   # adding other labels to the plot
   plot <- plot +
@@ -643,7 +763,7 @@ ggcoefstats <- function(x,
     ggstatsplot::theme_mprl(ggtheme = ggtheme) +
     ggplot2::theme(plot.caption = ggplot2::element_text(size = 10))
 
-  #================================================== output ===========================================================
+  # ================================================== output ===========================================================
   #
   # what needs to be returned?
   if (output == "plot") {
@@ -655,6 +775,6 @@ ggcoefstats <- function(x,
     return(glance_df)
   } else if (output == "augment") {
     return(broom::augment(x = x) %>%
-             tibble::as_data_frame(x = .))
+      tibble::as_data_frame(x = .))
   }
 }
