@@ -120,32 +120,31 @@
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/ggcorrmat.html}
 #'
 #' @examples
-#'
+#' 
 #' # to get the correlalogram
 #' ggstatsplot::ggcorrmat(
-#' data = datasets::iris,
-#' cor.vars = c(Sepal.Length:Petal.Width)
+#'   data = datasets::iris,
+#'   cor.vars = c(Sepal.Length:Petal.Width)
 #' )
-#'
+#' 
 #' # to get the correlation matrix
 #' ggstatsplot::ggcorrmat(
-#' data = datasets::iris,
-#' cor.vars = c(Sepal.Length:Petal.Width),
-#' output = "correlations"
+#'   data = datasets::iris,
+#'   cor.vars = c(Sepal.Length:Petal.Width),
+#'   output = "correlations"
 #' )
-#'
+#' 
 #' # setting output = "p-values" will return the p-value matrix
-#'
+#' 
 #' # modifying few elements of the correlation matrix by changing function defaults
 #' ggstatsplot::ggcorrmat(
-#' data = datasets::iris,
-#' cor.vars = c(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width),
-#' sig.level = 0.01,
-#' ggtheme = ggplot2::theme_bw,
-#' hc.order = TRUE, type = "lower", outline.col = "white",
-#' title = "Dataset: Iris"
+#'   data = datasets::iris,
+#'   cor.vars = c(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width),
+#'   sig.level = 0.01,
+#'   ggtheme = ggplot2::theme_bw,
+#'   hc.order = TRUE, type = "lower", outline.col = "white",
+#'   title = "Dataset: Iris"
 #' )
-#'
 #' @note If you are using R Notebook or Markdown and see a blank image being
 #'   inserted when a chunk is executed, this behavior can be turned off by
 #'   setting `legend.title.margin = FALSE`.
@@ -156,45 +155,45 @@
 # defining the function
 ggcorrmat <-
   function(data,
-           cor.vars,
-           cor.vars.names = NULL,
-           output = "plot",
-           type = "full",
-           method = "square",
-           corr.method = "pearson",
-           exact = FALSE,
-           continuity = TRUE,
-           beta = 0.1,
-           digits = 2,
-           sig.level = 0.05,
-           hc.order = FALSE,
-           hc.method = "complete",
-           lab = TRUE,
-           colors = c("#E69F00", "white", "#009E73"),
-           outline.color = "black",
-           ggtheme = ggplot2::theme_bw,
-           ggstatsplot.theme = TRUE,
-           title = NULL,
-           subtitle = NULL,
-           caption = NULL,
-           caption.default = TRUE,
-           lab.col = "black",
-           lab.size = 5,
-           insig = "pch",
-           pch = 4,
-           pch.col = "black",
-           pch.cex = 11,
-           tl.cex = 12,
-           tl.col = "black",
-           tl.srt = 45,
-           axis.text.x.margin.t = 0,
-           axis.text.x.margin.r = 0,
-           axis.text.x.margin.b = 0,
-           axis.text.x.margin.l = 0,
-           legend.title.margin = FALSE,
-           t.margin = unit(0, "mm"),
-           b.margin = unit(3, "mm"),
-           messages = TRUE) {
+             cor.vars,
+             cor.vars.names = NULL,
+             output = "plot",
+             type = "full",
+             method = "square",
+             corr.method = "pearson",
+             exact = FALSE,
+             continuity = TRUE,
+             beta = 0.1,
+             digits = 2,
+             sig.level = 0.05,
+             hc.order = FALSE,
+             hc.method = "complete",
+             lab = TRUE,
+             colors = c("#E69F00", "white", "#009E73"),
+             outline.color = "black",
+             ggtheme = ggplot2::theme_bw,
+             ggstatsplot.theme = TRUE,
+             title = NULL,
+             subtitle = NULL,
+             caption = NULL,
+             caption.default = TRUE,
+             lab.col = "black",
+             lab.size = 5,
+             insig = "pch",
+             pch = 4,
+             pch.col = "black",
+             pch.cex = 11,
+             tl.cex = 12,
+             tl.col = "black",
+             tl.srt = 45,
+             axis.text.x.margin.t = 0,
+             axis.text.x.margin.r = 0,
+             axis.text.x.margin.b = 0,
+             axis.text.x.margin.l = 0,
+             legend.title.margin = FALSE,
+             t.margin = unit(0, "mm"),
+             b.margin = unit(3, "mm"),
+             messages = TRUE) {
     # ========================================== dataframe ==============================================================
     #
     # creating a dataframe out of the entered variables
@@ -222,8 +221,8 @@ ggcorrmat <-
     # ========================================== statistics ==============================================================
     #
     if (corr.method == "pearson" ||
-        corr.method == "spearman" ||
-        corr.method == "kendall") {
+      corr.method == "spearman" ||
+      corr.method == "kendall") {
       # computing correlations on all included variables
       corr.mat <-
         base::round(
@@ -258,7 +257,7 @@ ggcorrmat <-
         dplyr::mutate_if(
           .tbl = .,
           .predicate = purrr::is_bare_double,
-          .funs = ~ base::round(x = ., digits = digits)
+          .funs = ~base::round(x = ., digits = digits)
         )
 
       # creating a correlation matrix of p-values
@@ -269,8 +268,8 @@ ggcorrmat <-
     # ========================================== plot ==============================================================
     if (output == "plot") {
       if (corr.method == "pearson" ||
-          corr.method == "spearman" ||
-          corr.method == "kendall") {
+        corr.method == "spearman" ||
+        corr.method == "kendall") {
         # plotting the correlalogram
         plot <- ggcorrplot::ggcorrplot(
           corr = corr.mat,
@@ -300,7 +299,7 @@ ggcorrmat <-
         #
         # if caption is not specified, use the generic version only if caption.default is TRUE
         if (is.null(caption) &&
-            pch == 4 && isTRUE(caption.default)) {
+          pch == 4 && isTRUE(caption.default)) {
           # adding text details to the plot
           plot <- plot +
             ggplot2::labs(
@@ -346,9 +345,11 @@ ggcorrmat <-
 
         # creating proper spacing between the legend.title and the colorbar
         if (isTRUE(legend.title.margin)) {
-          plot <- legend_title_margin(plot = plot,
-                                      t.margin = t.margin,
-                                      b.margin = b.margin)
+          plot <- legend_title_margin(
+            plot = plot,
+            t.margin = t.margin,
+            b.margin = b.margin
+          )
         }
       } else if (corr.method == "robust") {
         base::message(cat(
@@ -364,32 +365,32 @@ ggcorrmat <-
     # return the desired result
     if (output == "correlations") {
       if (corr.method == "pearson" ||
-          corr.method == "spearman" ||
-          corr.method == "kendall") {
+        corr.method == "spearman" ||
+        corr.method == "kendall") {
         # correlation matrix
         corr.mat %<>%
           base::as.data.frame(x = .) %>%
-          tibble::rownames_to_column(df = ., var = "variable") %>%
+          tibble::rownames_to_column(., var = "variable") %>%
           tibble::as_data_frame(x = .)
       }
       # return the tibble
       return(corr.mat)
     } else if (output == "p-values") {
       if (corr.method == "pearson" ||
-          corr.method == "spearman" ||
-          corr.method == "kendall") {
+        corr.method == "spearman" ||
+        corr.method == "kendall") {
         # p-value matrix
         p.mat %<>%
           base::as.data.frame(x = .) %>%
-          tibble::rownames_to_column(df = ., var = "variable") %>%
+          tibble::rownames_to_column(., var = "variable") %>%
           tibble::as_data_frame(x = .)
       }
       # return the final tibble
       return(p.mat)
     } else if (output == "plot") {
       if (corr.method == "pearson" ||
-          corr.method == "spearman" ||
-          corr.method == "kendall") {
+        corr.method == "spearman" ||
+        corr.method == "kendall") {
         # correlalogram plot
         return(plot)
       }
