@@ -101,7 +101,12 @@ utils::globalVariables(
     "partial.etasq",
     "partial.omegasq",
     "stratum",
-    "coefficient_type"
+    "coefficient_type",
+    "mean.y",
+    "n.y",
+    "sd.y",
+    "se.y",
+    "std.error"
   ),
   package = "ggstatsplot",
   add = FALSE
